# kick.py

Kick.py _will_ be an async api wrapper for [kick.com](https://kick.com) once the api is public, and is documented. Though once its there, I will gladly accept help in making this :D

# FAQ

> Q: Why does this package exist even though the api is not public yet?
>
> A: Because I'm too impatient, and want to start making the wrapper now
